==> apache-pulsar-3.0.15-src.tar.gz: apache-pulsar-3.0.15-src/pulsar-broker/src/main/java/org/apache/pulsar/broker/BookKeeperClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.broker;

import io.netty.channel.EventLoopGroup;
import java.util.Map;
import java.util.Optional;
import java.util.concurrent.CompletableFuture;
import org.apache.bookkeeper.client.BookKeeper;
import org.apache.bookkeeper.client.EnsemblePlacementPolicy;
import org.apache.bookkeeper.stats.StatsLogger;
import org.apache.pulsar.metadata.api.extended.MetadataStoreExtended;

/**
 * Provider of a new BookKeeper client instance.
 */
public interface BookKeeperClientFactory {
    CompletableFuture<BookKeeper> create(ServiceConfiguration conf, MetadataStoreExtended store,
                                         EventLoopGroup eventLoopGroup,
                                         Optional<Class<? extends EnsemblePlacementPolicy>> policyClass,
                                         Map<String, Object> ensemblePlacementPolicyProperties);

    CompletableFuture<BookKeeper> create(ServiceConfiguration conf, MetadataStoreExtended store,
                                         EventLoopGroup eventLoopGroup,
                                         Optional<Class<? extends EnsemblePlacementPolicy>> policyClass,
                                         Map<String, Object> ensemblePlacementPolicyProperties,
                                         StatsLogger statsLogger);

    void close();
}

==> apache-pulsar-3.3.0-src.tar.gz: apache-pulsar-3.3.0-src/pulsar-broker/src/main/java/org/apache/pulsar/broker/BookKeeperClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.broker;

import io.netty.channel.EventLoopGroup;
import java.io.IOException;
import java.util.Map;
import java.util.Optional;
import org.apache.bookkeeper.client.BookKeeper;
import org.apache.bookkeeper.client.EnsemblePlacementPolicy;
import org.apache.bookkeeper.stats.StatsLogger;
import org.apache.pulsar.metadata.api.extended.MetadataStoreExtended;

/**
 * Provider of a new BookKeeper client instance.
 */
public interface BookKeeperClientFactory {
    BookKeeper create(ServiceConfiguration conf, MetadataStoreExtended store, EventLoopGroup eventLoopGroup,
                      Optional<Class<? extends EnsemblePlacementPolicy>> ensemblePlacementPolicyClass,
                      Map<String, Object> ensemblePlacementPolicyProperties) throws IOException;

    BookKeeper create(ServiceConfiguration conf, MetadataStoreExtended store, EventLoopGroup eventLoopGroup,
                      Optional<Class<? extends EnsemblePlacementPolicy>> ensemblePlacementPolicyClass,
                      Map<String, Object> ensemblePlacementPolicyProperties,
                      StatsLogger statsLogger) throws IOException;
    void close();
}
